.. _nova-galaxy-docs:

============================================
nova-galaxy: Pythonic Galaxy Tool Automation
============================================

.. image:: https://img.shields.io/badge/Galaxy-nova--galaxy-blue.svg
   :target: https://code.ornl.gov/ndip/public-packages/nova-galaxy
   :alt: nova-galaxy

nova-galaxy is a Python library designed to simplify and streamline the interaction with Galaxy servers for tool execution and data management. It provides an intuitive and Pythonic way to automate Galaxy workflows, manage data, and integrate Galaxy tools into your Python applications.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   getting_started
   core_concepts/index
   examples/index
   api_reference
